# -*- coding: utf-8 -*-
from collective.flexmailhost.testing import COLLECTIVE_FLEXMAILHOST_FUNCTIONAL_TESTING
from collective.flexmailhost.testing import COLLECTIVE_FLEXMAILHOST_INTEGRATION_TESTING
from plone.app.testing import setRoles
from plone.app.testing import TEST_USER_ID

import unittest


class SubscriberIntegrationTest(unittest.TestCase):

    layer = COLLECTIVE_FLEXMAILHOST_INTEGRATION_TESTING

    def setUp(self):
        self.portal = self.layer["portal"]
        setRoles(self.portal, TEST_USER_ID, ["Manager"])


class SubscriberFunctionalTest(unittest.TestCase):

    layer = COLLECTIVE_FLEXMAILHOST_FUNCTIONAL_TESTING

    def setUp(self):
        self.portal = self.layer["portal"]
        setRoles(self.portal, TEST_USER_ID, ["Manager"])



from zope.sendmail.mailer import SMTPMailer
from zope.sendmail.mailer import _SMTPState


def default_init(
    self,
    hostname="localhost",
    port=25,
    username=None,
    password=None,
    no_tls=False,
    force_tls=False,
):
    self.hostname = hostname
    self.port = port
    self.username = username
    self.password = password
    self.force_tls = force_tls
    self.no_tls = no_tls
    self._smtp = _SMTPState()
    print("repatched SMTPMailer")


def apply_patches():
    SMTPMailer.__init__ = default_init



# -*- coding: utf-8 -*-
"""Init and utils."""
import logging

from zope.i18nmessageid import MessageFactory

from . import patches

log = logging.getLogger("collective.flexmailhost")

_ = MessageFactory("collective.flexmailhost")

patches.apply_patches()



# -*- coding: utf-8 -*-
from plone import api
from collective.flexmailhost import log


def handler(obj, event):
    """Event handler to sync mail setting with MailHost"""
    mailhost = api.portal.get_tool("MailHost")
    log.info(
        "Handle IMailSchema IRecordEvent for field '{}' to update MailHost settings.".format(
            event.record.fieldName
        )
    )
    if event.record.fieldName == "smtp_host":
        mailhost.smtp_host = event.newValue
    if event.record.fieldName == "smtp_port":
        mailhost.smtp_port = event.newValue
    if event.record.fieldName == "smtp_userid":
        mailhost.smtp_uid = event.newValue
    if event.record.fieldName == "smtp_pass":
        mailhost.smtp_pwd = event.newValue
